# BLM-OdI-Gen (Blackbird Language Matrices Object-Drop Alternation in Italian)

**Authors:**  
Chunyang Jiang 1,2, Giuseppe Samo 1, Vivi Nastase 1, Paola Merlo 1,2

1 Idiap Research Institute, Martigny, Switzerland

2 Department of Linguistics, University of Geneva, Switzerland


**Project / Funding:**  
DISLING/ Disentangling Linguistic Intelligence SNF Advanced grant  TMAG-1_209426 to PM

**Language:**  
Italian

**Size:**  
14M

**Dataset Type:**  
Synthetic dataset for object-drop alternation

**Keywords:**  
language intelligence test, synthetic data, object-drop alternation, verb alternation, verb argument structure

---

## Dataset Description

### Overview

**BLM-OdI-Gen** is a dataset in Italian for learning the underlying 
rules of object-drop alternation in sentences, developed in the 
**Blackbird Language Matrices** (**BLM**) framework 
(this dataset is a subset from the training data of 
https://www.idiap.ch/dataset/BLM-OdI). 
In this task, an instance consists of a sequence of sentences with specific attributes. 


To predict the correct answer as the next element of the sequence, 
a model must correctly detect the underlying generative rules used to produce the dataset. 
An instance represents the **object-drop alternation**, 
where the subject bears the same semantic role (Agent) in both the transitive 
and intransitive forms and the verb does not have a causative meaning.

---

### Blackbird Language Matrices (BLM) Task

BLM tasks are framed as **multiple-choice problems**. Given a context of sentences, each built using specific underlying rules, 
the goal is to predict the next correct sentence from a set of possible answers. 
Each answer set consists of one correct answer and multiple incorrect (contrastive) options. 
Incorrect options are generated by introducing variations that violate the underlying 
generative rules.

For **BLM-OdI**, the focus is on modeling how Italian verbs undergo 
**object-drop alternation**. The dataset captures this 
syntactic and semantic phenomenon in sentence sequences, 
with answer options that either preserve or violate these rules.

---

### Sub-tasks

**BLM-OdI-Gen** is one of six sub-tasks within the **BLM-It challenge**. 
Each sub-task is an instance of the general BLM framework, differing across two dimensions:
- **Linguistic problem:** Agreement (Agr), Causative/Inchoative Alternation (Caus), Object Drop Alternation (Od).
- **Lexical variation:** Type II (moderate lexical complexity) and Type III (higher lexical complexity).

Each instance in the dataset is categorized by **lexical variation** and split into **train/test** sets.

#### Data Splits
- **Type II**: 80 training samples, 2080 test samples.
- **Type III**: 80 training samples, 2080 test samples.

---

### Dataset Structure

The dataset is structured as a collection of JSON objects, where each object contains the following fields:

- **Lexical_variation**: The type of lexical variation (`type_II` or `type_III`).
- **ID**: A unique identifier for the instance.
- **Context**: A list of sentences representing the context.
- **Context_concatenated**: A concatenated string of context sentences, each prefixed by a numeral (1 to 7).
- **Answer_set**: A list of possible answer sentences.
- **Answer_concatenated**: A concatenated string of answer sentences, each prefixed by a letter (A, B, C, etc.).
- **Correct_option**: The correct answer option (a letter).
- **Correct_answer**: The correct answer sentence.
- **Answer_set_annotation**: A list of annotations for each answer option, containing the following:
  - **label**: Error type (e.g., `R-trans`, `I-Int`).
  - **value**: Boolean indicating whether the option is correct.
  - **option**: The corresponding option letter.
- **Verb**: The verb used in the instance. 

### Example

```json
    {
        "Lexical_variation": "type_III",
        "ID": 1772,
        "Context": [
            "1\talcuni tifosi stirarono i pantaloncini alla perfezione",
            "2\tLeonardo e Michelangelo devono poter dipingere i ponti sul Tevere da descrizioni in alcuni libri",
            "3\ti telai delle bici deve essere saldato dall'imbianchino senza fatica",
            "4\tdei piccoli giochi possono essere intagliati da alcuni turisti da questo pomeriggio",
            "5\ti pigiama sono stirati nelle stanze d'albergo",
            "6\tl'articolo deve essere letto da qualche minuto",
            "7\tla poetessa deve poter scrivere nel suo studio"
        ],
        "Context_concatenated": "1\talcuni tifosi stirarono i pantaloncini alla perfezione\n2\tLeonardo e Michelangelo devono poter dipingere i ponti sul Tevere da descrizioni in alcuni libri\n3\ti telai delle bici deve essere saldato dall'imbianchino senza fatica\n4\tdei piccoli giochi possono essere intagliati da alcuni turisti da questo pomeriggio\n5\ti pigiama sono stirati nelle stanze d'albergo\n6\tl'articolo deve essere letto da qualche minuto\n7\tla poetessa deve poter scrivere nel suo studio",
        "Answer_set": [
            "A\ti pigiama possono essere stirati dai calciatori della squadra",
            "B\tl'artista fu canticchiato dall'inno",
            "C\tuna carbonara può mangiare dalla zia ",
            "D\talcune coreografie devono disegnare le sue allieve",
            "E\ti loro calzini possono rammendare da soli",
            "F\tle turiste possono pescare da due balene",
            "G\tqueste studentesse devono poter disegnare da un mese",
            "H\til giornalista deve leggere il manuale di istruzioni"
        ],
        "Answer_concatenated": "A\ti pigiama possono essere stirati dai calciatori della squadra\nB\tl'artista fu canticchiato dall'inno\nC\tuna carbonara può mangiare dalla zia \nD\talcune coreografie devono disegnare le sue allieve\nE\ti loro calzini possono rammendare da soli\nF\tle turiste possono pescare da due balene\nG\tqueste studentesse devono poter disegnare da un mese\nH\til giornalista deve leggere il manuale di istruzioni",
        "Correct_option": "G",
        "Correct_answer": "queste studentesse devono poter disegnare da un mese",
        "Answer_set_annotation": [
            {
                "label": "IER-pass",
                "value": false,
                "option": "A"
            },
            {
                "label": "ER-pass",
                "value": false,
                "option": "B"
            },
            {
                "label": "IE-WrBy",
                "value": false,
                "option": "C"
            },
            {
                "label": "IR-trans",
                "value": false,
                "option": "D"
            },
            {
                "label": "I-Int",
                "value": false,
                "option": "E"
            },
            {
                "label": "E-WrBy",
                "value": false,
                "option": "F"
            },
            {
                "label": "Correct",
                "value": true,
                "option": "G"
            },
            {
                "label": "R-trans",
                "value": false,
                "option": "H"
            }
        ],
        "Verb": "disegnare"
    }
```


---

## Usage

### Loading the Dataset

To use the BLM-OdI-Gen dataset, you can load it using the Hugging Face `datasets` library:

```python
from datasets import load_dataset

train = load_dataset("XXX/BLM-OdI-Gen", split="train")

```

The dataset contains two splits (`train` and `test`) and grouped by lexical variation (`type_II` and `type_III`).


### Task Structure

The task follows a **multiple-choice format**, where:

- **Context**: A sequence of sentences (7 sentences) is given as the input.
- **Answer** set: A list of options is provided, where one is the correct continuation of the context, and others are distractors.
- **Objective**: The goal is to predict the correct next sentence by selecting from the answer set.

### Examople Use Case: Predicting the Correct Sentence

For each instance, the context represents a sequence of sentences demonstrating **object-drop alternation**. The model must analyze the context and select the correct sentence from the answer set.
   
Here’s an example of how you can extract the context and the answer set for a given instance:
```python

# Load one example from the dataset
example = train[0]

# Access the context
context = example["Context_concatenated"]
print("Context:\n", context)

# Access the answer set
answer_set = example["Answer_concatenated"]
print("\nAnswer Set:\n", answer_set)

# The correct answer option and sentence
correct_option = example["Correct_option"]
correct_answer = example["Correct_answer"]
print("\nCorrect Answer:\n", correct_option, "-", correct_answer)
```

### Model Training

When training a model on the **BLM-OdI-Gen** dataset, the **context** can be used as input, 
and the task is to predict the correct sentence from the **answer set**. 
You can formulate the task as a **sequence classification** or **multiple-choice task**.

Here's how you might prepare the data for training a model:

```python
# Preparing data for training a multiple-choice model
def prepare_inputs(example):
    return {
        "input_text": example["Context_concatenated"],
        "choices": example["Answer_set"],
        "label": ord(example["Correct_option"]) - 65  # Convert 'A' to 0, 'B' to 1, etc.
    }

# Apply the function to the training data
train_prepared = train.map(prepare_inputs)

# Example of the prepared input
train_prepared[0]
```
This structure can then be fed into a model designed for **multiple-choice classification**, where the input is the concatenated context, and the model selects the correct answer from the provided options.

### Example Use Case: Evaluating Model Predictions
After training, you can evaluate your model's predictions by comparing them with the ground truth. The dataset provides **annotations** for both correct and incorrect answers, allowing for in-depth error analysis.

```python
# Define a function to evaluate model predictions
def evaluate_predictions(model, dataset):
    correct = 0
    total = 0
    
    for instance in dataset:
        context = instance["Context_concatenated"]
        answer_set = instance["Answer_concatenated"].split("\n")
        
        # Model prediction (assuming your model returns the index of the predicted answer)
        predicted_index = model.predict(context, answer_set)
        correct_index = ord(instance["Correct_option"]) - 65  # 'A' = 0, 'B' = 1, etc.
        
        if predicted_index == correct_index:
            correct += 1
        total += 1

    accuracy = correct / total
    print(f"Model Accuracy: {accuracy:.2f}")

# Evaluate your model on the test set
evaluate_predictions(your_model, test)

```
### Example Use Case: Error Analysis
The **Answer_set_annotation** provides a detailed breakdown of the types of errors associated with each incorrect answer. You can use this to analyze where your model struggles and improve its performance.

For example, you can analyze errors like **ER-Pass** (a violation of an external rule, where the verb is not in the correct mood, resulting in a passive structure) by filtering the dataset:

```python
# Filter examples where the correct answer is missed due to a specific error type
error_type = "ER-Pass"
errors = [ex for ex in test if any(ann["label"] == error_type for ann in ex["Answer_set_annotation"])]

print(f"Found {len(errors)} examples with error type {error_type}")

# Display an example of an error with detailed annotation
for error in errors:
    print("Context:\n", error["Context_concatenated"])
    print("\nAnswer Set:\n", error["Answer_concatenated"])
    print("\nAnnotations:\n", error["Answer_set_annotation"])
    print("\nCorrect Answer:", error["Correct_answer"])
    break
```

### Few-Shot and Zero-Shot Learning
The **BLM-OdI-Gen** dataset is also well-suited for **few-shot learning** experiments, where you can test models' ability to generalize after being exposed to only a small number of examples.

To implement few-shot learning, sample a few examples from the training set and evaluate the model on the test set:

```python
# Sample 3 examples for few-shot learning
few_shot_train = train.shuffle(seed=42).select(range(3))

# Train your model on the few-shot examples
your_model.train(few_shot_train)

# Evaluate on the full test set
evaluate_predictions(your_model, test)
```

In zero-shot settings, you can directly evaluate your model on the test set without any training. This approach is particularly useful for benchmarking large language models (LLMs) like GPT4, LLama3, or similar models to test their inherent linguistic reasoning capabilities.


### How to Use

**BLM-OdI-Gen** is designed for testing a model's ability to identify and apply 
linguistic rules in a generative sequence. Use this dataset for tasks such as:
- **Evaluating language models** on understanding Italian **object-drop alternation**.
- **Benchmarking models** in a **multiple-choice reasoning task** with linguistic focus.
- **Comparing model performance** on tasks involving **syntactic alternation** in Italian verbs.

When training on the dataset, the context of each instance should be provided as input, and the task is to predict the next sentence by selecting from the answer set.

### Evaluation

Evaluate your model’s performance by comparing its predicted answer against the **Correct_option** field, which indicates the correct answer.

Metrics commonly used for evaluation include **accuracy**, **precision**, **recall**, and **F1-score**. You can also conduct error analysis based on the **Answer_set_annotation**, which indicates the types of errors made in the incorrect options.

---

## Citation

If you use this dataset in your research, please cite the corresponding paper (to appear):

```bibtex
@inproceedings{blm-it-gen-2024,
  title={BLM-It — Blackbird Language Matrices for Italian:  A CALAMITA Challenge},
  author={Chunyang Jiang, Giuseppe Samo, Vivi Nastase, Paola Merlo},
  booktitle={CLiC-it 2024: Tenth Italian Conference on Computational Linguistics},
  year={2024},
}
```

---

## Future Work and Best Practices

- **Consistency checks:** Ensure that your model maintains consistency across **lexical variations** (`type_II` and `type_III`) to capture generalization abilities.
- **Error analysis:** Use the provided **Answer_set_annotation** to study specific error types made by your model and improve fine-tuning.
- **Task-specific training:** Since the dataset is highly focused on a specific linguistic phenomenon, consider training models with task-specific objectives.
